/* n_run.c
 * Part of the RAMP project.
 * This file contains the code needed to run RAMP in ncurses mode
 * (MODE_NCURSES).
 * Written by Electronic One <eo@autobahn.mb.ca>.
 */

#include <stdio.h>
#include <ctype.h>  /* For toupper() */
#include <stdlib.h>
#include <string.h>

#include "switches.h"
#include "panel.h"
#include "screen.h"
#include "errorcodes.h"
#include "dialog.h"
#include "main_screen.h"
#include "open-close.h"
#include "decode.h"

void n_run(SW *sw)
{
   char *host, *host_or_file, *file;
   char s[100], quit = 0;
   WINDOW *w=NULL;
   FILE *inf=NULL, *outf=NULL;
   
   
   startup_ncurses();
   n_show_ver();
   bkgd(get_color(COLOR_WHITE, COLOR_BLACK));
   clear();
   load_main_screen();
   
   do
     {
	host_or_file = center_get_value("Read from (H)ost or (F)ile, or (Q)uit", 1);
	switch(toupper(*host_or_file))
	  {
	   case 'H':
	     sw->connect = 1;  /* Force connect to host mode */
	     host = center_get_value("Enter host to connect to", 60);
	     bcopy(host, &sw->host_name[0], strlen(host) + 1);
	     sprintf(s, "Connecting to: %s", host);
	     w = center_message(s);
	     break;
	     
	   case 'F':
	     sw->useinput = 1;
	     file = center_get_value("Enter file to read from", 60);
	     bcopy(file, &sw->inf_name[0], strlen(file) + 1);
	     sprintf(s, "Openning: %s", file);
	     w = center_message(s);
	     break;
	   
	   default:
	   case 'Q':
	     quit = 1;
	     break;
	  }
	
	if(!quit)  /* Make SURE quit gets processed first */
	  {
	     if(
		((inf = open_in(sw)) != NULL) &&
		((outf = open_out(sw)) != NULL)
		)
	       {
		  delwin(w);
		  refresh();
		  sprintf(s, "Playing sound.  Press any key to stop.");
		  w = center_message(s);
		  decode_sound(sw, inf, outf);
	       }
	  }
	
	/* Re-set switches for next time around */
	sw->connect = 0;
	sw->useinput = 0;
	
	/* Free up mem used by selection */
	free(host_or_file);

	if(!quit)
	  delwin(w);
	
	refresh();
	
	close_in(inf);
	close_out(outf);
     }
   while(!quit);

}


